@@ -13,14 +13,15 @@ use crate::cli::run;
 use crate::cli::run::{SelectorSource, Selectors};
 use crate::cli::{ExitStatus, HookType};
 use crate::fs::{CWD, Simplified};
-use crate::git::git_cmd;
+use crate::git::{GIT_ROOT, git_cmd};
 use crate::printer::Printer;
-use crate::store::STORE;
+use crate::store::Store;
 use crate::workspace::{Project, Workspace};
 use crate::{git, warn_user};
 
 #[allow(clippy::fn_params_excessive_bools)]
 pub(crate) async fn install(
+    store: &Store,
     config: Option<PathBuf>,
     includes: Vec<String>,
     skips: Vec<String>,
@@ -71,13 +72,14 @@ pub(crate) async fn install(
     }
 
     if install_hook_environments {
-        install_hooks(config, includes, skips, refresh, printer).await?;
+        install_hooks(store, config, includes, skips, refresh, printer).await?;
     }
 
     Ok(ExitStatus::Success)
 }
 
 pub(crate) async fn install_hooks(
+    store: &Store,
     config: Option<PathBuf>,
     includes: Vec<String>,
     skips: Vec<String>,
@@ -86,9 +88,9 @@ pub(crate) async fn install_hooks(
 ) -> Result<ExitStatus> {
     let workspace_root = Workspace::find_root(config.as_deref(), &CWD)?;
     let selectors = Selectors::load(&includes, &skips, &workspace_root)?;
-    let mut workspace = Workspace::discover(workspace_root, config, Some(&selectors), refresh)?;
+    let mut workspace =
+        Workspace::discover(store, workspace_root, config, Some(&selectors), refresh)?;
 
-    let store = STORE.as_ref()?;
     let reporter = HookInitReporter::from(printer);
     let _lock = store.lock_async().await?;
 
@@ -194,11 +196,27 @@ fn install_hook_script(
     // Otherwise, use the config path from the discovered project (workspace mode).
     // If neither is available, don't pass a config path (let prek find it). In this case,
     // we're different with `pre-commit` which always sets `--config=.pre-commit-config.yaml`.
-    if let Some(config) = config {
+    let target_info = if let Some(config) = config {
         args.push(format!(r#"--config="{}""#, config.display()));
+        format!(" with specified config `{}`", config.display().cyan())
     } else if let Some(project) = project {
-        args.push(format!(r#"--cd="{}""#, project.path().display()));
-    }
+        let project_path = project.path();
+        let relative_path = project_path
+            .strip_prefix(GIT_ROOT.as_ref()?)
+            .unwrap_or(project_path);
+        if !relative_path.as_os_str().is_empty() {
+            args.push(format!(r#"--cd="{}""#, relative_path.display()));
+        }
+
+        if project_path == GIT_ROOT.as_ref()? {
+            String::new()
+        } else {
+            // Show workspace path if it's not the root project.
+            format!(" for workspace `{}`", project_path.display().cyan())
+        }
+    } else {
+        String::new()
+    };
 
     if skip_on_missing_config {
         args.push("--skip-on-missing-config".to_string());
@@ -210,15 +228,15 @@ fn install_hook_script(
     let prek = prek.simplified().display().to_string();
     let hook_script = HOOK_TMPL
         .replace(
-            "#!SHEBANG",
+            "[SHEBANG]",
             if cfg!(windows) {
                 "#!/bin/sh"
             } else {
                 "#!/usr/bin/env bash"
             },
         )
-        .replace("ARGS=(hook-impl)", &format!("ARGS=({})", args.join(" ")))
-        .replace(r#"PREK="prek""#, &format!(r#"PREK="{prek}""#));
+        .replace("[PREK_ARGS]", &args.join(" "))
+        .replace("[PREK_PATH]", &format!(r#""{prek}""#));
 
     fs_err::OpenOptions::new()
         .write(true)
@@ -238,8 +256,8 @@ fn install_hook_script(
 
     writeln!(
         printer.stdout(),
-        "prek installed at `{}`",
-        hook_path.user_display().cyan()
+        "prek installed at `{}`{target_info}",
+        hook_path.user_display().cyan(),
     )?;
 
     Ok(())
@@ -247,17 +265,28 @@ fn install_hook_script(
 
 /// The version of the hook script. Increment this when the script changes in a way that
 /// requires re-installation.
-pub(crate) static CUR_SCRIPT_VERSION: usize = 2;
+pub(crate) static CUR_SCRIPT_VERSION: usize = 3;
 
-static HOOK_TMPL: &str = r#"#!SHEBANG
+static HOOK_TMPL: &str = r#"[SHEBANG]
 # File generated by prek: https://github.com/j178/prek
 # ID: 182c10f181da4464a3eec51b83331688
 
-ARGS=(hook-impl)
+# Unset GIT_DIR to avoid git taking current directory as the git dir.
+# See:
+# https://github.com/pre-commit/pre-commit/issues/2295
+# https://www.spinics.net/lists/git/msg374197.html
+unset GIT_DIR
+
+ARGS=([PREK_ARGS])
 
 HERE="$(cd "$(dirname "$0")" && pwd)"
 ARGS+=(--hook-dir "$HERE" -- "$@")
-PREK="prek"
+PREK=[PREK_PATH]
+
+# Check if the full path to prek is executable, otherwise fallback to PATH
+if [ ! -x "$PREK" ]; then
+    PREK="prek"
+fi
 
 exec "$PREK" "${ARGS[@]}"
 
@@ -324,6 +353,7 @@ pub(crate) async fn uninstall(
 }
 
 pub(crate) async fn init_template_dir(
+    store: &Store,
     directory: PathBuf,
     config: Option<PathBuf>,
     hook_types: Vec<HookType>,
@@ -332,6 +362,7 @@ pub(crate) async fn init_template_dir(
     printer: Printer,
 ) -> Result<ExitStatus> {
     install(
+        store,
         config,
         vec![],
         vec![],
