@@ -24,6 +24,7 @@ pub mod run;
 mod sample_config;
 #[cfg(feature = "self-update")]
 mod self_update;
+mod try_repo;
 mod validate;
 
 pub(crate) use auto_update::auto_update;
@@ -36,6 +37,7 @@ pub(crate) use run::run;
 pub(crate) use sample_config::sample_config;
 #[cfg(feature = "self-update")]
 pub(crate) use self_update::self_update;
+pub(crate) use try_repo::try_repo;
 pub(crate) use validate::{validate_configs, validate_manifest};
 
 #[derive(Copy, Clone)]
@@ -163,14 +165,26 @@ pub(crate) struct GlobalArgs {
     #[arg(global = true, long)]
     pub no_progress: bool,
 
-    /// Do not print any output.
-    #[arg(global = true, long, short, conflicts_with = "verbose")]
-    pub quiet: bool,
+    /// Use quiet output.
+    ///
+    /// Repeating this option, e.g., `-qq`, will enable a silent mode in which
+    /// prek will write no output to stdout.
+    #[arg(global = true, short, long, conflicts_with = "verbose", action = ArgAction::Count)]
+    pub quiet: u8,
 
     /// Use verbose output.
     #[arg(global = true, short, long, action = ArgAction::Count)]
     pub(crate) verbose: u8,
 
+    /// Write trace logs to the specified file.
+    /// If not specified, trace logs will be written to `$PREK_HOME/prek.log`.
+    #[arg(global = true, long, value_name = "LOG_FILE", value_hint = ValueHint::FilePath)]
+    pub(crate) log_file: Option<PathBuf>,
+
+    /// Do not write trace logs to a log file.
+    #[arg(global = true, long, overrides_with = "log_file", hide = true)]
+    pub(crate) no_log_file: bool,
+
     /// Display the prek version.
     #[arg(global = true, short = 'V', long, action = ArgAction::Version)]
     version: (),
@@ -205,15 +219,19 @@ pub(crate) enum Command {
     /// Auto-update pre-commit config to the latest repos' versions.
     #[command(alias = "autoupdate")]
     AutoUpdate(AutoUpdateArgs),
+    /// Manage the prek cache.
+    Cache(CacheNamespace),
     /// Clean unused cached repos.
+    #[command(hide = true)]
     GC,
-    /// Clean out pre-commit files.
+    /// Remove all prek cached data.
+    #[command(hide = true)]
     Clean,
     /// Install hook script in a directory intended for use with `git config init.templateDir`.
     #[command(alias = "init-templatedir")]
     InitTemplateDir(InitTemplateDirArgs),
     /// Try the pre-commit hooks in the current repo.
-    TryRepo(Box<RunArgs>),
+    TryRepo(Box<TryRepoArgs>),
     /// The implementation of the `pre-commit` hook.
     #[command(hide = true)]
     HookImpl(HookImplArgs),
@@ -386,6 +404,7 @@ pub(crate) struct RunArgs {
     #[arg(
         long,
         conflicts_with_all = ["all_files", "from_ref", "to_ref"],
+        num_args = 0..,
         value_hint = ValueHint::AnyPath)
     ]
     pub(crate) files: Vec<String>,
@@ -439,6 +458,19 @@ pub(crate) struct RunArgs {
     pub(crate) extra: RunExtraArgs,
 }
 
+#[derive(Debug, Clone, Default, Args)]
+pub(crate) struct TryRepoArgs {
+    /// Repository to source hooks from.
+    pub(crate) repo: String,
+
+    /// Manually select a rev to run against, otherwise the `HEAD` revision will be used.
+    #[arg(long, alias = "ref")]
+    pub(crate) rev: Option<String>,
+
+    #[command(flatten)]
+    pub(crate) run_args: RunArgs,
+}
+
 #[derive(Debug, Clone, Copy, clap::ValueEnum, Default, Serialize, Deserialize)]
 #[serde(rename_all = "kebab-case")]
 pub(crate) enum ListOutputFormat {
@@ -529,8 +561,11 @@ pub(crate) struct AutoUpdateArgs {
     /// Only update this repository. This option may be specified multiple times.
     #[arg(long)]
     pub(crate) repo: Vec<String>,
+    /// Do not write changes to the config file, only display what would be changed.
+    #[arg(long)]
+    pub(crate) dry_run: bool,
     /// Number of threads to use.
-    #[arg(short, long, default_value_t = 3)]
+    #[arg(short, long, default_value_t = 0)]
     pub(crate) jobs: usize,
 }
 
@@ -581,19 +616,35 @@ pub(crate) struct HookImplArgs {
 }
 
 #[derive(Debug, Args)]
-pub struct SelfNamespace {
+pub(crate) struct CacheNamespace {
     #[command(subcommand)]
-    pub command: SelfCommand,
+    pub(crate) command: CacheCommand,
 }
 
 #[derive(Debug, Subcommand)]
-pub enum SelfCommand {
+pub(crate) enum CacheCommand {
+    /// Show the location of the prek cache.
+    Dir,
+    /// Remove unused cached repositories, hook environments, and other data.
+    GC,
+    /// Remove all prek cached data.
+    Clean,
+}
+
+#[derive(Debug, Args)]
+pub(crate) struct SelfNamespace {
+    #[command(subcommand)]
+    pub(crate) command: SelfCommand,
+}
+
+#[derive(Debug, Subcommand)]
+pub(crate) enum SelfCommand {
     /// Update prek.
     Update(SelfUpdateArgs),
 }
 
 #[derive(Debug, Args)]
-pub struct SelfUpdateArgs {
+pub(crate) struct SelfUpdateArgs {
     /// Update to the specified version.
     /// If not provided, prek will update to the latest version.
     pub target_version: Option<String>,
