@@ -11,8 +11,8 @@ use rand::SeedableRng;
 use rand::prelude::{SliceRandom, StdRng};
 use rustc_hash::FxHashMap;
 use tokio::io::AsyncWriteExt;
-use tokio::sync::Semaphore;
-use tracing::{debug, trace};
+use tokio::sync::{OnceCell, Semaphore};
+use tracing::{debug, trace, warn};
 use unicode_width::UnicodeWidthStr;
 
 use constants::env_vars::EnvVars;
@@ -25,14 +25,15 @@ use crate::config::{Language, Stage};
 use crate::fs::CWD;
 use crate::git;
 use crate::git::GIT_ROOT;
-use crate::hook::{Hook, InstalledHook};
+use crate::hook::{Hook, InstallInfo, InstalledHook};
 use crate::printer::{Printer, Stdout};
 use crate::run::{CONCURRENCY, USE_COLOR};
-use crate::store::{STORE, Store};
+use crate::store::Store;
 use crate::workspace::{Project, Workspace};
 
 #[allow(clippy::too_many_arguments, clippy::fn_params_excessive_bools)]
 pub(crate) async fn run(
+    store: &Store,
     config: Option<PathBuf>,
     includes: Vec<String>,
     skips: Vec<String>,
@@ -76,13 +77,13 @@ pub(crate) async fn run(
 
     let workspace_root = Workspace::find_root(config.as_deref(), &CWD)?;
     let selectors = Selectors::load(&includes, &skips, &workspace_root)?;
-    let mut workspace = Workspace::discover(workspace_root, config, Some(&selectors), refresh)?;
+    let mut workspace =
+        Workspace::discover(store, workspace_root, config, Some(&selectors), refresh)?;
 
     if should_stash {
         workspace.check_configs_staged().await?;
     }
 
-    let store = STORE.as_ref()?;
     let reporter = HookInitReporter::from(printer);
     let lock = store.lock_async().await?;
 
@@ -221,14 +222,65 @@ fn set_env_vars(from_ref: Option<&String>, to_ref: Option<&String>, args: &RunEx
     }
 }
 
+#[derive(Debug)]
+struct LazyInstallInfo {
+    info: Arc<InstallInfo>,
+    health: OnceCell<bool>,
+}
+
+impl LazyInstallInfo {
+    fn new(info: Arc<InstallInfo>) -> Self {
+        Self {
+            info,
+            health: OnceCell::new(),
+        }
+    }
+
+    fn matches(&self, hook: &Hook) -> bool {
+        self.info.matches(hook)
+    }
+
+    fn info(&self) -> Arc<InstallInfo> {
+        self.info.clone()
+    }
+
+    async fn ensure_healthy(&self) -> bool {
+        let info = self.info.clone();
+        *self
+            .health
+            .get_or_init(|| async move {
+                match info.check_health().await {
+                    Ok(()) => true,
+                    Err(err) => {
+                        warn!(
+                            %err,
+                            path = %info.env_path.display(),
+                            "Skipping unhealthy installed hook"
+                        );
+                        false
+                    }
+                }
+            })
+            .await
+    }
+}
+
 pub async fn install_hooks(
     hooks: Vec<Arc<Hook>>,
     store: &Store,
     reporter: &HookInstallReporter,
 ) -> Result<Vec<InstalledHook>> {
     let num_hooks = hooks.len();
-    let mut installed_hooks = Vec::with_capacity(hooks.len());
-    let store_hooks = Rc::new(store.installed_hooks().collect::<Vec<_>>());
+    let mut result = Vec::with_capacity(hooks.len());
+
+    let store_hooks = Rc::new(
+        store
+            .installed_hooks()
+            .await
+            .into_iter()
+            .map(LazyInstallInfo::new)
+            .collect::<Vec<_>>(),
+    );
 
     // Group hooks by language to enable parallel installation across different languages.
     let mut hooks_by_language = FxHashMap::default();
@@ -255,27 +307,35 @@ pub async fn install_hooks(
                 let mut newly_installed = Vec::new();
 
                 for hook in hooks {
-                    // Find a matching installed hook environment.
-                    if let Some(info) = store_hooks
-                        .iter()
-                        .chain(newly_installed.iter().filter_map(|h| {
-                            if let InstalledHook::Installed { info, .. } = h {
-                                Some(info)
-                            } else {
-                                None
+                    let mut matched_info = None;
+
+                    for env in &newly_installed {
+                        if let InstalledHook::Installed { info, .. } = env {
+                            if info.matches(&hook) {
+                                matched_info = Some(info.clone());
+                                break;
                             }
-                        }))
-                        .find(|info| info.matches(&hook))
-                    {
+                        }
+                    }
+
+                    if matched_info.is_none() {
+                        for env in store_hooks.iter() {
+                            if env.matches(&hook) {
+                                if env.ensure_healthy().await {
+                                    matched_info = Some(env.info());
+                                    break;
+                                }
+                            }
+                        }
+                    }
+
+                    if let Some(info) = matched_info {
                         debug!(
                             "Found installed environment for hook `{}` at `{}`",
                             &hook,
                             info.env_path.display()
                         );
-                        hook_envs.push(InstalledHook::Installed {
-                            hook,
-                            info: info.clone(),
-                        });
+                        hook_envs.push(InstalledHook::Installed { hook, info });
                         continue;
                     }
 
@@ -312,18 +372,18 @@ pub async fn install_hooks(
         }
     }
 
-    while let Some(result) = futures.next().await {
-        installed_hooks.extend(result?);
+    while let Some(hooks) = futures.next().await {
+        result.extend(hooks?);
     }
     reporter.on_complete();
 
     debug_assert_eq!(
         num_hooks,
-        installed_hooks.len(),
+        result.len(),
         "Number of hooks installed should match the number of hooks provided"
     );
 
-    Ok(installed_hooks)
+    Ok(result)
 }
 
 /// Partition hooks into groups where hooks in the same group have same dependencies.
@@ -420,9 +480,13 @@ impl StatusPrinter {
         writeln!(self.printer.stdout(), "{line}")
     }
 
-    fn write_running(&self, hook_name: &str) -> Result<(), std::fmt::Error> {
+    fn write_running(&self, hook_name: &str, important: bool) -> Result<(), std::fmt::Error> {
         write!(
-            self.printer.stdout(),
+            if important {
+                self.printer.stdout_important()
+            } else {
+                self.printer.stdout()
+            },
             "{}{}",
             hook_name,
             ".".repeat(self.columns - hook_name.width_cjk() - Self::PASSED.len() - 1)
@@ -438,12 +502,16 @@ impl StatusPrinter {
     }
 
     fn write_failed(&self) -> Result<(), std::fmt::Error> {
-        writeln!(self.printer.stdout(), "{}", Self::FAILED.on_red())
+        writeln!(self.printer.stdout_important(), "{}", Self::FAILED.on_red())
     }
 
     fn stdout(&self) -> Stdout {
         self.printer.stdout()
     }
+
+    fn stdout_important(&self) -> Stdout {
+        self.printer.stdout_important()
+    }
 }
 
 /// Run all hooks.
@@ -480,6 +548,7 @@ async fn run_hooks(
 
     let projects_len = project_to_hooks.len();
     let mut first = true;
+    let mut file_modified = false;
 
     // Hooks might modify the files, so they must be run sequentially.
     'outer: for (_, mut hooks) in project_to_hooks {
@@ -500,22 +569,41 @@ async fn run_hooks(
         let fail_fast = project.config().fail_fast.unwrap_or(false);
 
         let filter = FileFilter::for_project(filenames.iter(), project);
-        trace!("Files for `{project}` after filtered: {}", filter.len());
+        trace!(
+            "Files for project `{project}` after filtered: {}",
+            filter.len()
+        );
 
+        let mut hook_succeed;
         for hook in hooks {
-            let (hook_success, new_diff) =
+            (hook_succeed, diff, file_modified) =
                 run_hook(hook, &filter, store, diff, verbose, dry_run, &printer).await?;
 
-            success &= hook_success;
-            diff = new_diff;
+            success &= hook_succeed;
             if !success && (fail_fast || hook.fail_fast) {
                 break 'outer;
             }
         }
     }
 
-    if !success && show_diff_on_failure {
-        writeln!(printer.stdout(), "All changes made by hooks:")?;
+    if !success && show_diff_on_failure && file_modified {
+        if EnvVars::is_set(EnvVars::CI) {
+            writeln!(
+                printer.stdout(),
+                "{}",
+                indoc::formatdoc! {
+                    "\n{}: Some hooks made changes to the files.
+                    If you are seeing this message in CI, reproduce locally with: `{}`
+                    To run prek as part of git workflow, use `{}` to set up git hooks.\n",
+                    "Hint".yellow().bold(),
+                    "prek run --all-files".cyan(),
+                    "prek install".cyan()
+                }
+            )?;
+        }
+
+        writeln!(printer.stdout_important(), "All changes made by hooks:")?;
+
         let color = if *USE_COLOR {
             "--color=always"
         } else {
@@ -557,10 +645,10 @@ async fn run_hook(
     verbose: bool,
     dry_run: bool,
     printer: &StatusPrinter,
-) -> Result<(bool, Vec<u8>)> {
+) -> Result<(bool, Vec<u8>, bool)> {
     let mut filenames = filter.for_hook(hook);
     trace!(
-        "Files for `{}` after filtered: {}",
+        "Files for hook `{}` after filtered: {}",
         hook.id,
         filenames.len()
     );
@@ -571,7 +659,7 @@ async fn run_hook(
             StatusPrinter::NO_FILES,
             Style::new().black().on_cyan(),
         )?;
-        return Ok((true, diff));
+        return Ok((true, diff, false));
     }
 
     if !Language::supported(hook.language) {
@@ -580,10 +668,10 @@ async fn run_hook(
             StatusPrinter::UNIMPLEMENTED,
             Style::new().black().on_yellow(),
         )?;
-        return Ok((true, diff));
+        return Ok((true, diff, false));
     }
 
-    printer.write_running(&hook.name)?;
+    printer.write_running(&hook.name, false)?;
     std::io::stdout().flush()?;
 
     let start = std::time::Instant::now();
@@ -626,57 +714,55 @@ async fn run_hook(
     } else if success {
         printer.write_passed()?;
     } else {
+        // If the printer is in quiet mode, the running line was not printed.
+        // Reprint it here before printing the failure.
+        if printer.stdout() == Stdout::Disabled {
+            printer.write_running(&hook.name, true)?;
+        }
         printer.write_failed()?;
     }
 
     if verbose || hook.verbose || !success {
-        writeln!(
-            printer.stdout(),
-            "{}",
-            format!("- hook id: {}", hook.id).dimmed()
-        )?;
+        let mut stdout = if success {
+            printer.stdout()
+        } else {
+            printer.stdout_important()
+        };
+
+        writeln!(stdout, "{}", format!("- hook id: {}", hook.id).dimmed())?;
         if verbose || hook.verbose {
             writeln!(
-                printer.stdout(),
+                stdout,
                 "{}",
                 format!("- duration: {:.2?}s", duration.as_secs_f64()).dimmed()
             )?;
         }
         if status != 0 {
-            writeln!(
-                printer.stdout(),
-                "{}",
-                format!("- exit code: {status}").dimmed()
-            )?;
+            writeln!(stdout, "{}", format!("- exit code: {status}").dimmed())?;
         }
         if file_modified {
-            writeln!(
-                printer.stdout(),
-                "{}",
-                "- files were modified by this hook".dimmed()
-            )?;
+            writeln!(stdout, "{}", "- files were modified by this hook".dimmed())?;
         }
 
-        // To be consistent with pre-commit, merge stderr into stdout.
-        let stdout = output.trim_ascii();
-        if !stdout.is_empty() {
+        let output = output.trim_ascii();
+        if !output.is_empty() {
             if let Some(file) = hook.log_file.as_deref() {
                 let mut file = fs_err::tokio::OpenOptions::new()
                     .create(true)
                     .append(true)
                     .open(file)
                     .await?;
-                file.write_all(stdout).await?;
+                file.write_all(output).await?;
                 file.sync_all().await?;
             } else {
                 writeln!(
-                    printer.stdout(),
+                    stdout,
                     "{}",
-                    textwrap::indent(&String::from_utf8_lossy(stdout), "  ").dimmed()
+                    textwrap::indent(&String::from_utf8_lossy(output), "  ").dimmed()
                 )?;
             }
         }
     }
 
-    Ok((success, new_diff))
+    Ok((success, new_diff, file_modified))
 }
