@@ -19,10 +19,6 @@
 // THE SOFTWARE.
 
 use std::io::{BufRead, Read};
-#[cfg(unix)]
-use std::os::unix::fs::FileTypeExt;
-#[cfg(unix)]
-use std::os::unix::fs::PermissionsExt;
 use std::path::Path;
 use std::sync::OnceLock;
 use std::vec;
@@ -720,7 +716,7 @@ fn is_encoding_tag(tag: &str) -> bool {
     matches!(tag, tags::TEXT | tags::BINARY)
 }
 
-pub fn tags_from_path(path: &Path) -> Result<Vec<&str>> {
+pub(crate) fn tags_from_path(path: &Path) -> Result<Vec<&str>> {
     let metadata = std::fs::symlink_metadata(path)?;
     if metadata.is_dir() {
         return Ok(vec![tags::DIRECTORY]);
@@ -729,6 +725,7 @@ pub fn tags_from_path(path: &Path) -> Result<Vec<&str>> {
     }
     #[cfg(unix)]
     {
+        use std::os::unix::fs::FileTypeExt;
         let file_type = metadata.file_type();
         if file_type.is_socket() {
             return Ok(vec![tags::SOCKET]);
@@ -744,13 +741,19 @@ pub fn tags_from_path(path: &Path) -> Result<Vec<&str>> {
     let mut tags = FxHashSet::default();
     tags.insert(tags::FILE);
 
+    let executable;
     #[cfg(unix)]
-    let executable = metadata.permissions().mode() & 0o111 != 0;
+    {
+        use std::os::unix::fs::PermissionsExt;
+        executable = metadata.permissions().mode() & 0o111 != 0;
+    }
     #[cfg(not(unix))]
-    let executable = {
-        let ext = path.extension().and_then(|ext| ext.to_str());
-        ext.is_some_and(|ext| ext == "exe" || ext == "bat" || ext == "cmd")
-    };
+    {
+        executable = {
+            let ext = path.extension().and_then(|ext| ext.to_str());
+            ext.is_some_and(|ext| ext == "exe" || ext == "bat" || ext == "cmd")
+        };
+    }
 
     if executable {
         tags.insert(tags::EXECUTABLE);
@@ -800,7 +803,8 @@ fn tags_from_filename(filename: &Path) -> Vec<&str> {
     }
 
     if let Some(ext) = ext {
-        if let Some(tags) = by_extension().get(ext) {
+        let ext = ext.to_lowercase();
+        if let Some(tags) = by_extension().get(ext.as_str()) {
             result.extend(tags);
         }
     }
@@ -809,22 +813,25 @@ fn tags_from_filename(filename: &Path) -> Vec<&str> {
 }
 
 fn tags_from_interpreter(interpreter: &str) -> Vec<&'static str> {
-    let Some(pos) = interpreter.rfind('/') else {
-        return Vec::new();
-    };
-    let mut name = &interpreter[pos + 1..];
-    // python3.12.3 should match python3.12.3, python3.12, python3, python
-    loop {
+    let mut name = interpreter
+        .rfind('/')
+        .map(|pos| &interpreter[pos + 1..])
+        .unwrap_or(interpreter);
+
+    while !name.is_empty() {
         if let Some(tags) = by_interpreter().get(name) {
             return tags.clone();
         }
+
+        // python3.12.3 should match python3.12.3, python3.12, python3, python
         if let Some(pos) = name.rfind('.') {
             name = &name[..pos];
         } else {
             break;
         }
     }
-    vec![]
+
+    Vec::new()
 }
 
 #[derive(thiserror::Error, Debug)]
@@ -883,6 +890,12 @@ pub(crate) fn parse_shebang(path: &Path) -> Result<Vec<String>, ShebangError> {
     Ok(cmd)
 }
 
+fn is_text_char(b: u8) -> bool {
+    (0x20..0x7F).contains(&b) // Printable ASCII
+        || b >= 0x80 // High bit set
+        || [7, 8, 9, 10, 11, 12, 13, 27].contains(&b) // Control characters
+}
+
 /// Return whether the first KB of contents seems to be binary.
 ///
 /// This is roughly based on libmagic's binary/text detection:
@@ -900,17 +913,7 @@ fn is_text_file(path: &Path) -> bool {
         return true;
     }
 
-    let text_chars: Vec<u8> = (0..=255)
-        .filter(|&x| {
-            (0x20..=0x7E).contains(&x) // Printable ASCII
-                || x >= 0x80 // High bit set
-                || [7, 8, 9, 10, 11, 12, 13, 27].contains(&x) // Control characters
-        })
-        .collect();
-
-    buffer[..bytes_read]
-        .iter()
-        .all(|&b| text_chars.contains(&b))
+    buffer[..bytes_read].iter().all(|&b| is_text_char(b))
 }
 
 pub fn all_tags() -> &'static FxHashSet<&'static str> {
@@ -989,5 +992,32 @@ mod tests {
 
         let tags = super::tags_from_filename(Path::new("Pipfile.lock"));
         assert_eq!(tags, vec!["json", "text"]);
+
+        let tags = super::tags_from_filename(Path::new("file.pdf"));
+        assert_eq!(tags, vec!["pdf", "binary"]);
+
+        let tags = super::tags_from_filename(Path::new("FILE.PDF"));
+        assert_eq!(tags, vec!["pdf", "binary"]);
+    }
+
+    #[test]
+    fn tags_from_interpreter() {
+        let tags = super::tags_from_interpreter("/usr/bin/python3");
+        assert_eq!(tags, vec!["python", "python3"]);
+
+        let tags = super::tags_from_interpreter("/usr/bin/python3.12");
+        assert_eq!(tags, vec!["python", "python3"]);
+
+        let tags = super::tags_from_interpreter("/usr/bin/python3.12.3");
+        assert_eq!(tags, vec!["python", "python3"]);
+
+        let tags = super::tags_from_interpreter("python");
+        assert_eq!(tags, vec!["python"]);
+
+        let tags = super::tags_from_interpreter("sh");
+        assert_eq!(tags, vec!["shell", "sh"]);
+
+        let tags = super::tags_from_interpreter("invalid");
+        assert_eq!(tags, Vec::<&str>::new());
     }
 }
