@@ -38,7 +38,7 @@ impl LanguageImpl for Golang {
             _ => unreachable!(),
         };
         let go = installer
-            .install(version)
+            .install(store, version)
             .await
             .context("Failed to install go")?;
 
@@ -95,12 +95,11 @@ impl LanguageImpl for Golang {
                 .await?;
         }
         for dep in &hook.additional_dependencies {
-            go_install_cmd()
-                .arg(dep)
-                .remove_git_env()
-                .check(true)
-                .output()
-                .await?;
+            let mut cmd = go_install_cmd();
+            if let Some(repo) = hook.repo_path() {
+                cmd.current_dir(repo);
+            }
+            cmd.arg(dep).remove_git_env().check(true).output().await?;
         }
 
         reporter.on_install_complete(progress);
@@ -111,8 +110,8 @@ impl LanguageImpl for Golang {
         })
     }
 
-    async fn check_health(&self) -> anyhow::Result<()> {
-        todo!()
+    async fn check_health(&self, _info: &InstallInfo) -> anyhow::Result<()> {
+        Ok(())
     }
 
     async fn run(
@@ -121,10 +120,8 @@ impl LanguageImpl for Golang {
         filenames: &[&Path],
         store: &Store,
     ) -> anyhow::Result<(i32, Vec<u8>)> {
-        let env_dir = hook.env_path().expect("Node must have env path");
-        let InstalledHook::Installed { hook, info } = hook else {
-            unreachable!()
-        };
+        let env_dir = hook.env_path().expect("Node hook must have env path");
+        let info = hook.install_info().expect("Node hook must be installed");
 
         let go_bin = bin_dir(env_dir);
         let go_tools = store.tools_path(ToolBucket::Go);
