@@ -12,9 +12,9 @@ use crate::archive::ArchiveExtension;
 use crate::cli::reporter::HookInstallReporter;
 use crate::config::Language;
 use crate::fs::CWD;
-use crate::hook::{Hook, InstalledHook};
+use crate::hook::{Hook, InstallInfo, InstalledHook};
 use crate::identify::parse_shebang;
-use crate::store::{STORE, Store};
+use crate::store::Store;
 use crate::version::version;
 use crate::{archive, builtin};
 
@@ -47,7 +47,7 @@ trait LanguageImpl {
         store: &Store,
         reporter: &HookInstallReporter,
     ) -> Result<InstalledHook>;
-    async fn check_health(&self) -> Result<()>;
+    async fn check_health(&self, info: &InstallInfo) -> Result<()>;
     async fn run(
         &self,
         hook: &InstalledHook,
@@ -72,7 +72,7 @@ impl LanguageImpl for Unimplemented {
         Ok(InstalledHook::NoNeedInstall(hook))
     }
 
-    async fn check_health(&self) -> Result<()> {
+    async fn check_health(&self, _info: &InstallInfo) -> Result<()> {
         Ok(())
     }
 
@@ -179,18 +179,18 @@ impl Language {
         }
     }
 
-    pub async fn check_health(&self) -> Result<()> {
+    pub async fn check_health(&self, info: &InstallInfo) -> Result<()> {
         match self {
-            Self::Golang => GOLANG.check_health().await,
-            Self::Python => PYTHON.check_health().await,
-            Self::Node => NODE.check_health().await,
-            Self::System => SYSTEM.check_health().await,
-            Self::Fail => FAIL.check_health().await,
-            Self::Docker => DOCKER.check_health().await,
-            Self::DockerImage => DOCKER_IMAGE.check_health().await,
-            Self::Script => SCRIPT.check_health().await,
-            Self::Pygrep => PYGREP.check_health().await,
-            _ => UNIMPLEMENTED.check_health().await,
+            Self::Golang => GOLANG.check_health(info).await,
+            Self::Python => PYTHON.check_health(info).await,
+            Self::Node => NODE.check_health(info).await,
+            Self::System => SYSTEM.check_health(info).await,
+            Self::Fail => FAIL.check_health(info).await,
+            Self::Docker => DOCKER.check_health(info).await,
+            Self::DockerImage => DOCKER_IMAGE.check_health(info).await,
+            Self::Script => SCRIPT.check_health(info).await,
+            Self::Pygrep => PYGREP.check_health(info).await,
+            _ => UNIMPLEMENTED.check_health(info).await,
         }
     }
 
@@ -202,7 +202,7 @@ impl Language {
     ) -> Result<(i32, Vec<u8>)> {
         // fast path for hooks implemented in Rust
         if builtin::check_fast_path(hook) {
-            return builtin::run_fast_path(hook, filenames).await;
+            return builtin::run_fast_path(store, hook, filenames).await;
         }
 
         match self {
@@ -263,6 +263,7 @@ async fn download_and_extract(
     client: &reqwest::Client,
     url: &str,
     filename: &str,
+    store: &Store,
     callback: impl AsyncFn(&Path) -> Result<()>,
 ) -> Result<()> {
     let response = client
@@ -285,10 +286,10 @@ async fn download_and_extract(
         .into_async_read()
         .compat();
 
-    let scratch = STORE.as_ref()?.scratch_path();
-    fs_err::tokio::create_dir_all(&scratch).await?;
+    let scratch_dir = store.scratch_path();
+    fs_err::tokio::create_dir_all(&scratch_dir).await?;
 
-    let temp_dir = tempfile::tempdir_in(&scratch)?;
+    let temp_dir = tempfile::tempdir_in(&scratch_dir)?;
     debug!(url = %url, temp_dir = ?temp_dir.path(), "Downloading");
 
     let ext = ArchiveExtension::from_path(filename)?;
@@ -302,7 +303,7 @@ async fn download_and_extract(
 
     callback(&extracted).await?;
 
-    fs_err::tokio::remove_dir_all(temp_dir.path()).await?;
+    drop(temp_dir);
 
     Ok(())
 }
