@@ -1,6 +1,6 @@
 use std::borrow::Cow;
 use std::env::consts::EXE_EXTENSION;
-use std::path::Path;
+use std::path::{Path, PathBuf};
 use std::sync::Arc;
 
 use anyhow::{Context, Result};
@@ -13,7 +13,7 @@ use crate::hook::InstalledHook;
 use crate::hook::{Hook, InstallInfo};
 use crate::languages::LanguageImpl;
 use crate::languages::node::NodeRequest;
-use crate::languages::node::installer::{NodeInstaller, bin_dir, lib_dir};
+use crate::languages::node::installer::{NodeInstaller, NodeResult, bin_dir, lib_dir};
 use crate::languages::node::version::EXTRA_KEY_LTS;
 use crate::languages::version::LanguageRequest;
 use crate::process::Cmd;
@@ -49,7 +49,7 @@ impl LanguageImpl for Node {
             _ => unreachable!(),
         };
         let node = installer
-            .install(node_request)
+            .install(store, node_request)
             .await
             .context("Failed to install node")?;
 
@@ -129,8 +129,21 @@ impl LanguageImpl for Node {
         })
     }
 
-    async fn check_health(&self) -> Result<()> {
-        todo!()
+    async fn check_health(&self, info: &InstallInfo) -> Result<()> {
+        let node = NodeResult::from_executables(info.toolchain.clone(), PathBuf::new())
+            .fill_version()
+            .await
+            .context("Failed to query node version")?;
+
+        if node.version().version != info.language_version {
+            anyhow::bail!(
+                "Node version mismatch: expected {}, found {}",
+                info.language_version,
+                node.version().version
+            );
+        }
+
+        Ok(())
     }
 
     async fn run(
