@@ -20,9 +20,9 @@ use crate::store::{CacheBucket, Store};
 use crate::version;
 
 // The version range of `uv` we will install. Should update periodically.
-const CUR_UV_VERSION: &str = "0.8.17";
+const CUR_UV_VERSION: &str = "0.9.0";
 static UV_VERSION_RANGE: LazyLock<VersionReq> =
-    LazyLock::new(|| VersionReq::parse(">=0.7.0, <0.9.0").unwrap());
+    LazyLock::new(|| VersionReq::parse(">=0.7.0, <0.10.0").unwrap());
 
 // Get the uv wheel platform tag for the current host.
 fn get_wheel_platform_tag() -> Result<String> {
@@ -70,7 +70,7 @@ fn get_uv_version(uv_path: &Path) -> Result<Version> {
     let output = Command::new(uv_path)
         .arg("--version")
         .output()
-        .map_err(|e| anyhow::anyhow!("Failed to execute uv: {}", e))?;
+        .map_err(|e| anyhow::anyhow!("Failed to execute uv: {e}"))?;
 
     if !output.status.success() {
         bail!("Failed to get uv version");
@@ -142,15 +142,15 @@ enum InstallSource {
 }
 
 impl InstallSource {
-    async fn install(&self, target: &Path) -> Result<()> {
+    async fn install(&self, store: &Store, target: &Path) -> Result<()> {
         match self {
-            Self::GitHub => self.install_from_github(target).await,
-            Self::PyPi(source) => self.install_from_pypi(target, source).await,
+            Self::GitHub => self.install_from_github(store, target).await,
+            Self::PyPi(source) => self.install_from_pypi(store, target, source).await,
             Self::Pip => self.install_from_pip(target).await,
         }
     }
 
-    async fn install_from_github(&self, target: &Path) -> Result<()> {
+    async fn install_from_github(&self, store: &Store, target: &Path) -> Result<()> {
         let ext = if cfg!(windows) { "zip" } else { "tar.gz" };
         let archive_name = format!("uv-{HOST}.{ext}");
         let download_url = format!(
@@ -158,28 +158,39 @@ impl InstallSource {
         );
 
         let client = reqwest::Client::new();
-        download_and_extract(&client, &download_url, &archive_name, async |extracted| {
-            let source = extracted.join("uv").with_extension(EXE_EXTENSION);
-            let target_path = target.join("uv").with_extension(EXE_EXTENSION);
+        download_and_extract(
+            &client,
+            &download_url,
+            &archive_name,
+            store,
+            async |extracted| {
+                let source = extracted.join("uv").with_extension(EXE_EXTENSION);
+                let target_path = target.join("uv").with_extension(EXE_EXTENSION);
 
-            if target_path.exists() {
-                debug!(target = %target.display(), "Removing existing uv");
-                fs_err::tokio::remove_dir_all(&target).await?;
-            }
+                if target_path.exists() {
+                    debug!(target = %target.display(), "Removing existing uv");
+                    fs_err::tokio::remove_dir_all(&target).await?;
+                }
 
-            debug!(?source, target = %target_path.display(), "Moving uv to target");
-            // TODO: retry on Windows
-            fs_err::tokio::rename(source, target_path).await?;
+                debug!(?source, target = %target_path.display(), "Moving uv to target");
+                // TODO: retry on Windows
+                fs_err::tokio::rename(source, target_path).await?;
 
-            anyhow::Ok(())
-        })
+                anyhow::Ok(())
+            },
+        )
         .await
         .context("Failed to download and extra uv")?;
 
         Ok(())
     }
 
-    async fn install_from_pypi(&self, target: &Path, source: &PyPiMirror) -> Result<()> {
+    async fn install_from_pypi(
+        &self,
+        store: &Store,
+        target: &Path,
+        source: &PyPiMirror,
+    ) -> Result<()> {
         let platform_tag = get_wheel_platform_tag()?;
         let wheel_name = format!("uv-{CUR_UV_VERSION}-py3-none-{platform_tag}.whl");
 
@@ -188,7 +199,7 @@ impl InstallSource {
         let api_url = match source {
             PyPiMirror::Pypi => format!("https://pypi.org/pypi/uv/{CUR_UV_VERSION}/json"),
             // For mirrors, we'll fall back to simple API approach
-            _ => return self.install_from_simple_api(target, source).await,
+            _ => return self.install_from_simple_api(store, target, source).await,
         };
 
         debug!("Fetching uv metadata from: {}", api_url);
@@ -219,18 +230,23 @@ impl InstallSource {
                     && file["yanked"].as_bool() != Some(true)
             })
             .ok_or_else(|| {
-                anyhow::anyhow!("Could not find wheel for {} in PyPI response", wheel_name)
+                anyhow::anyhow!("Could not find wheel for {wheel_name} in PyPI response")
             })?;
 
         let download_url = wheel_file["url"]
             .as_str()
             .ok_or_else(|| anyhow::anyhow!("Missing download URL in PyPI response"))?;
 
-        self.download_and_extract_wheel(&client, target, &wheel_name, download_url)
+        self.download_and_extract_wheel(store, &client, target, &wheel_name, download_url)
             .await
     }
 
-    async fn install_from_simple_api(&self, target: &Path, source: &PyPiMirror) -> Result<()> {
+    async fn install_from_simple_api(
+        &self,
+        store: &Store,
+        target: &Path,
+        source: &PyPiMirror,
+    ) -> Result<()> {
         // Fallback for mirrors that don't support JSON API
         let platform_tag = get_wheel_platform_tag()?;
         let wheel_name = format!("uv-{CUR_UV_VERSION}-py3-none-{platform_tag}.whl");
@@ -264,8 +280,7 @@ impl InstallSource {
             })
             .ok_or_else(|| {
                 anyhow::anyhow!(
-                    "Could not find wheel download link for {} in simple API response",
-                    wheel_name
+                    "Could not find wheel download link for {wheel_name} in simple API response"
                 )
             })?;
 
@@ -276,18 +291,19 @@ impl InstallSource {
             format!("{simple_url}{download_path}")
         };
 
-        self.download_and_extract_wheel(&client, target, &wheel_name, &download_url)
+        self.download_and_extract_wheel(store, &client, target, &wheel_name, &download_url)
             .await
     }
 
     async fn download_and_extract_wheel(
         &self,
+        store: &Store,
         client: &reqwest::Client,
         target: &Path,
         filename: &str,
         download_url: &str,
     ) -> Result<()> {
-        download_and_extract(client, download_url, filename, async |extracted| {
+        download_and_extract(client, download_url, filename, store, async |extracted| {
             // Find the uv binary in the extracted contents
             let data_dir = format!("uv-{CUR_UV_VERSION}.data");
             let extracted_uv = extracted
@@ -333,15 +349,25 @@ impl InstallSource {
             .arg("install")
             .arg("--prefix")
             .arg(target)
+            .arg("--only-binary=:all:")
+            .arg("--progress-bar=off")
+            .arg("--disable-pip-version-check")
             .arg(format!("uv=={CUR_UV_VERSION}"))
             .check(true)
-            .status()
+            .output()
             .await?;
 
-        let bin_dir = target.join(if cfg!(windows) { "Scripts" } else { "bin" });
-        let lib_dir = target.join(if cfg!(windows) { "Lib" } else { "lib" });
+        let local_dir = target.join("local");
+        let uv_src = if local_dir.is_dir() {
+            &local_dir
+        } else {
+            target
+        };
 
-        let uv = target
+        let bin_dir = uv_src.join(if cfg!(windows) { "Scripts" } else { "bin" });
+        let lib_dir = uv_src.join(if cfg!(windows) { "Lib" } else { "lib" });
+
+        let uv = uv_src
             .join(&bin_dir)
             .join("uv")
             .with_extension(EXE_EXTENSION);
@@ -403,7 +429,6 @@ impl Uv {
 
             while let Some(result) = tasks.join_next().await {
                 if let Ok((source, response)) = result {
-                    trace!(?source, ?response, "Checked source");
                     if let Ok(resp) = response
                         && resp.status().is_success()
                     {
@@ -416,27 +441,22 @@ impl Uv {
             Ok(best)
         }
 
-        let source = if cfg!(feature = "uv-source-github") {
-            InstallSource::GitHub
-        } else if cfg!(feature = "uv-source-pypi") {
-            InstallSource::PyPi(PyPiMirror::Pypi)
-        } else {
-            let client = reqwest::Client::new();
-            tokio::select! {
+        let client = reqwest::Client::new();
+        let source = tokio::select! {
                 Ok(true) = check_github(&client) => InstallSource::GitHub,
                 Ok(source) = select_best_pypi(&client) => InstallSource::PyPi(source),
                 else => {
                     warn!("Failed to check uv source availability, falling back to pip install");
                     InstallSource::Pip
                 }
-            }
+
         };
 
         trace!(?source, "Selected uv source");
         Ok(source)
     }
 
-    pub(crate) async fn install(uv_dir: &Path) -> Result<Self> {
+    pub(crate) async fn install(store: &Store, uv_dir: &Path) -> Result<Self> {
         // 1) Check `uv` alongside `prek` binary (e.g. `uv tool install prek --with uv`)
         let prek_exe = std::env::current_exe()?.canonicalize()?;
         if let Some(prek_dir) = prek_exe.parent() {
@@ -482,13 +502,34 @@ impl Uv {
             return Ok(Self::new(uv_path));
         }
 
-        let source = Self::select_source().await?;
-        source.install(uv_dir).await?;
+        let source = if let Some(uv_source) = uv_source_from_env() {
+            uv_source
+        } else {
+            Self::select_source().await?
+        };
+        source.install(store, uv_dir).await?;
 
         Ok(Self::new(uv_path))
     }
 }
 
+fn uv_source_from_env() -> Option<InstallSource> {
+    let var = EnvVars::var(EnvVars::PREK_UV_SOURCE).ok()?;
+    match var.as_str() {
+        "github" => Some(InstallSource::GitHub),
+        "pypi" => Some(InstallSource::PyPi(PyPiMirror::Pypi)),
+        "tuna" => Some(InstallSource::PyPi(PyPiMirror::Tuna)),
+        "aliyun" => Some(InstallSource::PyPi(PyPiMirror::Aliyun)),
+        "tencent" => Some(InstallSource::PyPi(PyPiMirror::Tencent)),
+        "pip" => Some(InstallSource::Pip),
+        custom if custom.starts_with("http") => Some(InstallSource::PyPi(PyPiMirror::Custom(var))),
+        _ => {
+            warn!("Invalid UV_SOURCE value: {}", var);
+            None
+        }
+    }
+}
+
 #[test]
 fn ensure_cur_uv_version_in_range() {
     let version = Version::parse(CUR_UV_VERSION).expect("Invalid CUR_UV_VERSION");
