@@ -1,4 +1,5 @@
 use std::fmt::Write;
+use std::path::PathBuf;
 use std::process::ExitCode;
 use std::str::FromStr;
 use std::sync::Mutex;
@@ -17,12 +18,12 @@ use tracing_subscriber::util::SubscriberInitExt;
 use tracing_subscriber::{EnvFilter, Layer};
 
 use crate::cleanup::cleanup;
-use crate::cli::{Cli, Command, ExitStatus};
+use crate::cli::{CacheCommand, CacheNamespace, Cli, Command, ExitStatus};
 #[cfg(feature = "self-update")]
 use crate::cli::{SelfCommand, SelfNamespace, SelfUpdateArgs};
 use crate::printer::Printer;
 use crate::run::USE_COLOR;
-use crate::store::STORE;
+use crate::store::Store;
 
 mod archive;
 mod builtin;
@@ -59,7 +60,29 @@ pub(crate) enum Level {
     TraceAll,
 }
 
-fn setup_logging(level: Level) -> Result<()> {
+enum LogFile {
+    Default,
+    Path(PathBuf),
+    Disabled,
+}
+
+impl LogFile {
+    fn from_args(log_file: Option<PathBuf>, no_log_file: bool) -> Self {
+        if no_log_file {
+            Self::Disabled
+        } else if let Some(path) = log_file {
+            Self::Path(path)
+        } else {
+            Self::Default
+        }
+    }
+
+    fn is_disabled(&self) -> bool {
+        matches!(self, Self::Disabled)
+    }
+}
+
+fn setup_logging(level: Level, log_file: LogFile, store: &Store) -> Result<()> {
     let directive = match level {
         Level::Default | Level::Verbose => LevelFilter::OFF.into(),
         Level::Debug => Directive::from_str("prek=debug")?,
@@ -81,28 +104,35 @@ fn setup_logging(level: Level) -> Result<()> {
         .with_writer(anstream::stderr)
         .with_filter(stderr_filter);
 
-    let log_file_path = STORE.as_ref()?.log_file();
-    let log_file = fs_err::OpenOptions::new()
-        .create(true)
-        .write(true)
-        .truncate(true)
-        .open(log_file_path)
-        .context("Failed to open log file")?;
-    let log_file = Mutex::new(StripStream::new(log_file.into_file()));
+    let registry = tracing_subscriber::registry().with(stderr_layer);
 
-    let file_format = tracing_subscriber::fmt::format()
-        .with_target(false)
-        .with_ansi(false);
-    let file_layer = tracing_subscriber::fmt::layer()
-        .with_span_events(FmtSpan::CLOSE)
-        .event_format(file_format)
-        .with_writer(log_file)
-        .with_filter(EnvFilter::new("prek=trace"));
+    if log_file.is_disabled() {
+        registry.init();
+    } else {
+        let log_file_path = match log_file {
+            LogFile::Default => store.log_file(),
+            LogFile::Path(path) => path,
+            LogFile::Disabled => unreachable!(),
+        };
+        let log_file = fs_err::OpenOptions::new()
+            .create(true)
+            .write(true)
+            .truncate(true)
+            .open(log_file_path)
+            .context("Failed to open log file")?;
+        let log_file = Mutex::new(StripStream::new(log_file.into_file()));
 
-    tracing_subscriber::registry()
-        .with(stderr_layer)
-        .with(file_layer)
-        .init();
+        let file_format = tracing_subscriber::fmt::format()
+            .with_target(false)
+            .with_ansi(false);
+        let file_layer = tracing_subscriber::fmt::layer()
+            .with_span_events(FmtSpan::CLOSE)
+            .event_format(file_format)
+            .with_writer(log_file)
+            .with_filter(EnvFilter::new("prek=trace"));
+
+        registry.with(file_layer).init();
+    }
 
     Ok(())
 }
@@ -110,16 +140,24 @@ fn setup_logging(level: Level) -> Result<()> {
 async fn run(mut cli: Cli) -> Result<ExitStatus> {
     ColorChoice::write_global(cli.globals.color.into());
 
-    setup_logging(match cli.globals.verbose {
-        0 => Level::Default,
-        1 => Level::Verbose,
-        2 => Level::Debug,
-        3 => Level::Trace,
-        _ => Level::TraceAll,
-    })?;
+    let store = Store::from_settings()?;
+    let log_file = LogFile::from_args(cli.globals.log_file.clone(), cli.globals.no_log_file);
+    setup_logging(
+        match cli.globals.verbose {
+            0 => Level::Default,
+            1 => Level::Verbose,
+            2 => Level::Debug,
+            3 => Level::Trace,
+            _ => Level::TraceAll,
+        },
+        log_file,
+        &store,
+    )?;
 
-    let printer = if cli.globals.quiet {
+    let printer = if cli.globals.quiet == 1 {
         Printer::Quiet
+    } else if cli.globals.quiet > 1 {
+        Printer::Silent
     } else if cli.globals.verbose > 1 {
         Printer::Verbose
     } else if cli.globals.no_progress {
@@ -128,7 +166,7 @@ async fn run(mut cli: Cli) -> Result<ExitStatus> {
         Printer::Default
     };
 
-    if cli.globals.quiet {
+    if cli.globals.quiet > 0 {
         warnings::disable();
     } else {
         warnings::enable();
@@ -138,11 +176,14 @@ async fn run(mut cli: Cli) -> Result<ExitStatus> {
         cli.command = Some(Command::Run(Box::new(cli.run_args.clone())));
     }
 
+    debug!("prek: {}", version::version());
+
     if let Some(dir) = cli.globals.cd.as_ref() {
+        debug!("Changing current directory to: `{}`", dir.display());
         std::env::set_current_dir(dir)?;
     }
 
-    debug!("prek: {}", version::version());
+    debug!("Args: {:?}", std::env::args().collect::<Vec<_>>());
 
     macro_rules! show_settings {
         ($arg:expr) => {
@@ -164,6 +205,7 @@ async fn run(mut cli: Cli) -> Result<ExitStatus> {
             show_settings!(args);
 
             cli::install(
+                &store,
                 cli.globals.config,
                 args.includes,
                 args.skips,
@@ -180,6 +222,7 @@ async fn run(mut cli: Cli) -> Result<ExitStatus> {
         Command::InstallHooks(args) => {
             // TODO: add selectors?
             cli::install_hooks(
+                &store,
                 cli.globals.config,
                 args.includes,
                 args.skips,
@@ -197,6 +240,7 @@ async fn run(mut cli: Cli) -> Result<ExitStatus> {
             show_settings!(args);
 
             cli::run(
+                &store,
                 cli.globals.config,
                 args.includes,
                 args.skips,
@@ -220,6 +264,7 @@ async fn run(mut cli: Cli) -> Result<ExitStatus> {
             show_settings!(args);
 
             cli::list(
+                &store,
                 cli.globals.config,
                 args.includes,
                 args.skips,
@@ -236,6 +281,7 @@ async fn run(mut cli: Cli) -> Result<ExitStatus> {
             show_settings!(args);
 
             cli::hook_impl(
+                &store,
                 cli.globals.config,
                 args.includes,
                 args.skips,
@@ -248,7 +294,20 @@ async fn run(mut cli: Cli) -> Result<ExitStatus> {
             )
             .await
         }
-        Command::Clean => cli::clean(printer),
+        Command::Cache(CacheNamespace {
+            command: cache_command,
+        }) => match cache_command {
+            CacheCommand::Clean => cli::clean(&store, printer),
+            CacheCommand::Dir => {
+                writeln!(printer.stdout(), "{}", store.path().display().cyan())?;
+                Ok(ExitStatus::Success)
+            }
+            CacheCommand::GC => {
+                writeln!(printer.stderr(), "Command not implemented yet")?;
+                Ok(ExitStatus::Failure)
+            }
+        },
+        Command::Clean => cli::clean(&store, printer),
         Command::ValidateConfig(args) => {
             show_settings!(args);
 
@@ -262,11 +321,27 @@ async fn run(mut cli: Cli) -> Result<ExitStatus> {
         Command::SampleConfig(args) => cli::sample_config(args.file, printer),
         Command::AutoUpdate(args) => {
             cli::auto_update(
+                &store,
                 cli.globals.config,
                 args.repo,
                 args.bleeding_edge,
                 args.freeze,
                 args.jobs,
+                args.dry_run,
+                printer,
+            )
+            .await
+        }
+        Command::TryRepo(args) => {
+            show_settings!(args);
+
+            cli::try_repo(
+                cli.globals.config,
+                args.repo,
+                args.rev,
+                args.run_args,
+                cli.globals.refresh,
+                cli.globals.verbose > 0,
                 printer,
             )
             .await
@@ -302,6 +377,7 @@ async fn run(mut cli: Cli) -> Result<ExitStatus> {
             show_settings!(args);
 
             cli::init_template_dir(
+                &store,
                 args.directory,
                 cli.globals.config,
                 args.hook_types,
