@@ -1,12 +1,13 @@
 use std::hash::{DefaultHasher, Hash, Hasher};
 use std::io::Write;
 use std::path::{Path, PathBuf};
-use std::sync::{Arc, LazyLock};
+use std::sync::Arc;
 
 use anyhow::Result;
 use etcetera::BaseStrategy;
+use futures::StreamExt;
 use thiserror::Error;
-use tracing::debug;
+use tracing::{debug, warn};
 
 use constants::env_vars::EnvVars;
 
@@ -14,6 +15,7 @@ use crate::config::RemoteRepo;
 use crate::fs::LockedFile;
 use crate::git::clone_repo;
 use crate::hook::InstallInfo;
+use crate::run::CONCURRENCY;
 use crate::workspace::HookInitReporter;
 
 #[derive(Debug, Error)]
@@ -28,23 +30,6 @@ pub enum Error {
     Serde(#[from] serde_json::Error),
 }
 
-pub(crate) static STORE: LazyLock<Result<Store, Error>> = LazyLock::new(|| {
-    let path = if let Some(path) = EnvVars::var_os(EnvVars::PREK_HOME) {
-        Some(path.into())
-    } else {
-        etcetera::choose_base_strategy()
-            .map(|path| path.cache_dir().join("prek"))
-            .ok()
-    };
-
-    let Some(path) = path else {
-        return Err(Error::HomeNotFound);
-    };
-    let store = Store::from_path(path).init()?;
-
-    Ok(store)
-});
-
 /// A store for managing repos.
 #[derive(Debug)]
 pub struct Store {
@@ -56,6 +41,24 @@ impl Store {
         Self { path: path.into() }
     }
 
+    /// Create a store from environment variables or default paths.
+    pub(crate) fn from_settings() -> Result<Self, Error> {
+        let path = if let Some(path) = EnvVars::var_os(EnvVars::PREK_HOME) {
+            Some(path.into())
+        } else {
+            etcetera::choose_base_strategy()
+                .map(|path| path.cache_dir().join("prek"))
+                .ok()
+        };
+
+        let Some(path) = path else {
+            return Err(Error::HomeNotFound);
+        };
+        let store = Store::from_path(path).init()?;
+
+        Ok(store)
+    }
+
     pub(crate) fn path(&self) -> &Path {
         self.path.as_ref()
     }
@@ -98,7 +101,7 @@ impl Store {
 
         debug!(
             target = %temp.path().display(),
-            ?repo,
+            %repo,
             "Cloning repo",
         );
         clone_repo(&repo.repo, &repo.rev, temp.path()).await?;
@@ -118,22 +121,39 @@ impl Store {
     }
 
     /// Returns installed hooks in the store.
-    pub(crate) fn installed_hooks(&self) -> impl Iterator<Item = Arc<InstallInfo>> {
-        fs_err::read_dir(self.hooks_dir())
-            .ok()
-            .into_iter()
-            .flatten()
-            .flatten()
-            .filter_map(|entry| {
-                let path = entry.path();
-                let mut file = fs_err::File::open(path.join(".prek-hook.json")).ok()?;
-                serde_json::from_reader(&mut file).map(Arc::new).ok()
-            })
-    }
+    pub(crate) async fn installed_hooks(&self) -> Vec<Arc<InstallInfo>> {
+        let Ok(dirs) = fs_err::read_dir(self.hooks_dir()) else {
+            return vec![];
+        };
 
-    /// Lock the store.
-    pub(crate) fn lock(&self) -> Result<LockedFile, std::io::Error> {
-        LockedFile::acquire_blocking(self.path.join(".lock"), "store")
+        let mut tasks = futures::stream::iter(dirs)
+            .map(async |entry| {
+                let path = match entry {
+                    Ok(entry) => entry.path(),
+                    Err(err) => {
+                        warn!(%err, "Failed to read hook dir");
+                        return None;
+                    }
+                };
+                let info = match InstallInfo::from_env_path(&path).await {
+                    Ok(info) => info,
+                    Err(err) => {
+                        warn!(%err, path = %path.display(), "Skipping invalid installed hook");
+                        return None;
+                    }
+                };
+                Some(info)
+            })
+            .buffer_unordered(*CONCURRENCY);
+
+        let mut hooks = Vec::new();
+        while let Some(hook) = tasks.next().await {
+            if let Some(hook) = hook {
+                hooks.push(Arc::new(hook));
+            }
+        }
+
+        hooks
     }
 
     pub(crate) async fn lock_async(&self) -> Result<LockedFile, std::io::Error> {
