@@ -361,43 +361,14 @@ fn mixed_line_ending_hook() -> Result<()> {
     ");
     assert_snapshot!(context.read("mixed.txt"), @"line1\r\nline2\r\n");
 
-    // Test mixed args with --fix crlf
+    // Test mixed args with missing value for `--fix`
     context.write_pre_commit_config(indoc::indoc! {r"
         repos:
           - repo: https://github.com/pre-commit/pre-commit-hooks
             rev: v5.0.0
             hooks:
               - id: mixed-line-ending
-                args: ['--verbose', '--fix', 'crlf', '--help']
-    "});
-    context
-        .work_dir()
-        .child("mixed.txt")
-        .write_str("line1\nline2\r\nline3\n")?;
-    context.git_add(".");
-    cmd_snapshot!(context.filters(), context.run(), @r"
-    success: false
-    exit_code: 1
-    ----- stdout -----
-    mixed line ending........................................................Failed
-    - hook id: mixed-line-ending
-    - exit code: 1
-    - files were modified by this hook
-      Fixing .pre-commit-config.yaml
-      Fixing mixed.txt
-
-    ----- stderr -----
-    ");
-    assert_snapshot!(context.read("mixed.txt"), @"line1\r\nline2\r\nline3\r\n");
-
-    // Test mixed args with --fix crlf
-    context.write_pre_commit_config(indoc::indoc! {r"
-        repos:
-          - repo: https://github.com/pre-commit/pre-commit-hooks
-            rev: v5.0.0
-            hooks:
-              - id: mixed-line-ending
-                args: ['--verbose', '--fix']
+                args: ['--fix']
     "});
     context
         .work_dir()
@@ -411,7 +382,8 @@ fn mixed_line_ending_hook() -> Result<()> {
     mixed line ending........................................................
     ----- stderr -----
     error: Failed to run hook `mixed-line-ending`
-      caused by: Missing value for `--fix` argument
+      caused by: error: a value is required for '--fix <FIX>' but none was supplied
+      [possible values: auto, no, lf, crlf, cr]
     ");
 
     Ok(())
@@ -786,3 +758,230 @@ fn fix_byte_order_marker_hook() -> Result<()> {
 
     Ok(())
 }
+
+#[test]
+#[cfg(unix)]
+fn check_symlinks_hook_unix() -> Result<()> {
+    let context = TestContext::new();
+    context.init_project();
+    context.configure_git_author();
+
+    context.write_pre_commit_config(indoc::indoc! {r"
+        repos:
+          - repo: https://github.com/pre-commit/pre-commit-hooks
+            rev: v5.0.0
+            hooks:
+              - id: check-symlinks
+    "});
+
+    let cwd = context.work_dir();
+
+    // Create test files
+    cwd.child("regular.txt").write_str("regular file")?;
+    cwd.child("target.txt").write_str("target content")?;
+
+    // Create valid symlink
+    std::os::unix::fs::symlink(
+        cwd.child("target.txt").path(),
+        cwd.child("valid_link.txt").path(),
+    )?;
+
+    // Create broken symlink
+    std::os::unix::fs::symlink(
+        cwd.child("nonexistent.txt").path(),
+        cwd.child("broken_link.txt").path(),
+    )?;
+
+    context.git_add(".");
+
+    // First run: should fail due to broken symlink
+    cmd_snapshot!(context.filters(), context.run(), @r#"
+    success: false
+    exit_code: 1
+    ----- stdout -----
+    check for broken symlinks................................................Failed
+    - hook id: check-symlinks
+    - exit code: 1
+      broken_link.txt: Broken symlink
+
+    ----- stderr -----
+    "#);
+
+    // Remove broken symlink
+    std::fs::remove_file(cwd.child("broken_link.txt").path())?;
+    context.git_add(".");
+
+    // Second run: should pass
+    cmd_snapshot!(context.filters(), context.run(), @r#"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+    check for broken symlinks................................................Passed
+
+    ----- stderr -----
+    "#);
+
+    Ok(())
+}
+
+#[test]
+#[cfg(windows)]
+fn check_symlinks_hook_windows() -> Result<()> {
+    let context = TestContext::new();
+    context.init_project();
+    context.configure_git_author();
+
+    context.write_pre_commit_config(indoc::indoc! {r"
+        repos:
+          - repo: https://github.com/pre-commit/pre-commit-hooks
+            rev: v5.0.0
+            hooks:
+              - id: check-symlinks
+    "});
+
+    let cwd = context.work_dir();
+
+    // Create test files
+    cwd.child("regular.txt").write_str("regular file")?;
+    cwd.child("target.txt").write_str("target content")?;
+
+    // Try to create valid symlink (may fail without admin/developer mode)
+    let valid_link_result = std::os::windows::fs::symlink_file(
+        cwd.child("target.txt").path(),
+        cwd.child("valid_link.txt").path(),
+    );
+
+    // Try to create broken symlink (may fail without admin/developer mode)
+    let broken_link_result = std::os::windows::fs::symlink_file(
+        cwd.child("nonexistent.txt").path(),
+        cwd.child("broken_link.txt").path(),
+    );
+
+    // Skip test if we can't create symlinks (insufficient permissions)
+    if valid_link_result.is_err() || broken_link_result.is_err() {
+        // Skipping test: insufficient permissions for symlink creation on Windows
+        return Ok(());
+    }
+
+    context.git_add(".");
+
+    // First run: should fail due to broken symlink
+    cmd_snapshot!(context.filters(), context.run(), @r#"
+    success: false
+    exit_code: 1
+    ----- stdout -----
+    check for broken symlinks................................................Failed
+    - hook id: check-symlinks
+    - exit code: 1
+      broken_link.txt: Broken symlink
+
+    ----- stderr -----
+    "#);
+
+    // Remove broken symlink
+    std::fs::remove_file(cwd.child("broken_link.txt").path())?;
+    context.git_add(".");
+
+    // Second run: should pass
+    cmd_snapshot!(context.filters(), context.run(), @r#"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+    check for broken symlinks................................................Passed
+
+    ----- stderr -----
+    "#);
+
+    Ok(())
+}
+
+#[test]
+fn detect_private_key_hook() -> Result<()> {
+    let context = TestContext::new();
+    context.init_project();
+    context.configure_git_author();
+
+    context.write_pre_commit_config(indoc::indoc! {r"
+        repos:
+          - repo: https://github.com/pre-commit/pre-commit-hooks
+            rev: v5.0.0
+            hooks:
+              - id: detect-private-key
+    "});
+
+    let cwd = context.work_dir();
+
+    // Create test files - various private key types
+    cwd.child("id_rsa")
+        .write_str("-----BEGIN RSA PRIVATE KEY-----\nMIIE...\n-----END RSA PRIVATE KEY-----\n")?;
+    cwd.child("id_dsa")
+        .write_str("-----BEGIN DSA PRIVATE KEY-----\nAAAAA...\n-----END DSA PRIVATE KEY-----\n")?;
+    cwd.child("id_ecdsa")
+        .write_str("-----BEGIN EC PRIVATE KEY-----\nMHc...\n-----END EC PRIVATE KEY-----\n")?;
+    cwd.child("id_ed25519").write_str(
+        "-----BEGIN OPENSSH PRIVATE KEY-----\nb3BlbnNz...\n-----END OPENSSH PRIVATE KEY-----\n",
+    )?;
+    cwd.child("key.ppk")
+        .write_str("PuTTY-User-Key-File-2: ssh-rsa\nEncryption: none\n")?;
+    cwd.child("private.asc")
+        .write_str("-----BEGIN PGP PRIVATE KEY BLOCK-----\nVersion: GnuPG...\n")?;
+    cwd.child("ta.key").write_str(
+        "#\n# 2048 bit OpenVPN static key\n#\n-----BEGIN OpenVPN Static key V1-----\n",
+    )?;
+    cwd.child("doc.txt").write_str(
+        "Some documentation\n\nHere is a key:\n-----BEGIN RSA PRIVATE KEY-----\ndata\n",
+    )?;
+    cwd.child("safe1.txt")
+        .write_str("This file talks about BEGIN_RSA_PRIVATE_KEY but doesn't contain one\n")?;
+
+    cwd.child("safe2.txt")
+        .write_str("This is just a regular file\nwith some content\n")?;
+    cwd.child("empty.txt").touch()?;
+
+    context.git_add(".");
+
+    // First run: hooks should fail due to private keys
+    cmd_snapshot!(context.filters(), context.run(), @r"
+    success: false
+    exit_code: 1
+    ----- stdout -----
+    detect private key.......................................................Failed
+    - hook id: detect-private-key
+    - exit code: 1
+      Private key found: doc.txt
+      Private key found: id_ecdsa
+      Private key found: key.ppk
+      Private key found: id_rsa
+      Private key found: id_dsa
+      Private key found: id_ed25519
+      Private key found: ta.key
+      Private key found: private.asc
+
+    ----- stderr -----
+    ");
+
+    // Remove all private keys
+    context.git_rm("id_rsa");
+    context.git_rm("id_dsa");
+    context.git_rm("id_ecdsa");
+    context.git_rm("id_ed25519");
+    context.git_rm("key.ppk");
+    context.git_rm("private.asc");
+    context.git_rm("ta.key");
+    context.git_rm("doc.txt");
+    context.git_clean();
+
+    context.git_add(".");
+
+    // Second run: hooks should now pass
+    cmd_snapshot!(context.filters(), context.run(), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+    detect private key.......................................................Passed
+
+    ----- stderr -----
+    ");
+
+    Ok(())
+}
